import { BASE_URL } from './constants';
import { ApiResponse } from './types';
import { unpack } from './utils';

const send = async <T>(
  url: string,
  init: RequestInit,
): Promise<ApiResponse<T>> => {
  const fullURL = `${BASE_URL}/${url}`;
  const fullInit: RequestInit = { ...init };
  try {
    const response = await fetch(fullURL, fullInit);
    if (!response.ok) {
      return {
        data: null,
        error: { status: response.status, message: 'Something went wrong' },
      };
    }
    const raw = await response.json();
    const data: T = unpack(raw);
    return { data: data, error: null };
  } catch {
    return {
      data: null,
      error: { status: 0, message: 'Something went wrong' },
    };
  }
};

export const api = {
  get: async <T>(url: string) => {
    return send<T>(url, { method: 'GET' });
  },
  post: async <T>(url: string, body: unknown) => {
    return send<T>(url, {
      method: 'POST',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify(body),
    });
  },
  put: async <T>(url: string, body: unknown) => {
    return send<T>(url, {
      method: 'PUT',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify(body),
    });
  },
  delete: async <T>(url: string) => {
    return send<T>(url, { method: 'DELETE' });
  },
};
