import { deletePark, getParks, Park } from '@api/wind';
import { Button, Heading } from '@components/ui';
import { DataGrid } from '@components/ui/data-grid';
import { ROUTES, useRoute } from '@utils/route';
import React, { useEffect, useState } from 'react';
import { Link } from 'react-router-dom';

import { columns } from './constants';
import styles from './styles.module.scss';

export function ParksPage() {
  const [parks, setParks] = useState<Park[]>([]);
  const [selected, setSelected] = useState<Park>(null);
  const route = useRoute();

  const fetchParks = async () => {
    const res = await getParks();
    setParks(res.data);
  };

  useEffect(() => {
    fetchParks();
  }, []);

  const handleParkSelect = (items: Park[]) => {
    setSelected(items[0] ?? null);
  };

  const handleDeleteButtonClick = async () => {
    await deletePark(selected.id);
    fetchParks();
  };

  return (
    <div className={styles.page}>
      <Heading tag="h1">{route.title}</Heading>
      <div className={styles.actions}>
        <Link to={ROUTES.park.path.replace(':id', 'new')}>
          <Button>Create new</Button>
        </Link>
        {selected && (
          <Link to={ROUTES.park.path.replace(':id', String(selected.id))}>
            <Button variant="secondary">Edit</Button>
          </Link>
        )}
        {selected && (
          <Button variant="secondary" onClick={handleDeleteButtonClick}>
            Delete
          </Button>
        )}
      </div>
      <div className={styles.dataGridWrapper}>
        <DataGrid
          items={parks}
          columns={columns}
          getItemKey={({ id }) => String(id)}
          selectedItems={selected ? [selected] : []}
          onItemsSelect={handleParkSelect}
          multiselect={false}
        />
      </div>
    </div>
  );
}
