import {
  createTurbineTypes,
  editTurbineTypes,
  getTurbineType,
  TurbineType,
} from '@api/wind';
import { Button, Heading, NumberField, TextInput } from '@components/ui';
import { Controller, useForm } from '@utils/form';
import { ROUTES, useRoute } from '@utils/route';
import React, { useEffect, useState } from 'react';
import { useNavigate, useParams } from 'react-router-dom';

import styles from './styles.module.scss';
import { TurbineTypeFormValues } from './types';
import { unpackTurbineType } from './utils';

export function TurbineTypePage() {
  const [turbineType, setTurbineType] = useState<TurbineType>(null);
  const [pending, setPending] = useState<boolean>(false);
  const params = useParams();
  const navigate = useNavigate();
  const route = useRoute();

  const { register, control, getValues, reset } =
    useForm<TurbineTypeFormValues>({});

  const { id } = params;
  const isEdit = id !== 'new';
  const heading = isEdit ? 'Edit' : 'Create new';

  const fetchTurbineType = async () => {
    const response = await getTurbineType(id);
    setTurbineType(response.data);
    reset(unpackTurbineType(response.data));
  };

  useEffect(() => {
    if (!isEdit) {
      return;
    }
    fetchTurbineType();
  }, [id]);

  const handleSubmit = async (event: React.FormEvent) => {
    event.preventDefault();
    setPending(true);
    if (isEdit) {
      const response = await editTurbineTypes(getValues(), id);
      setTurbineType(response.data);
      reset(unpackTurbineType(response.data));
    } else {
      const response = await createTurbineTypes(getValues());
      navigate(
        ROUTES.turbineType.path.replace(':id', String(response.data.id)),
      );
    }
    setPending(false);
  };

  const handleReset = () => {
    if (isEdit) {
      reset(unpackTurbineType(turbineType));
    } else {
      reset({});
    }
  };

  return (
    <div className={styles.page} onSubmit={handleSubmit}>
      <Heading tag="h1">{route.title}</Heading>
      <form className={styles.form}>
        <header>
          <Heading tag="h3">{heading}</Heading>
        </header>
        <TextInput {...register('name')} label={{ text: 'Name' }} />
        <div className={styles.inputBox}>
          <Controller
            {...control('height')}
            render={(props) => (
              <NumberField label={{ text: 'Height' }} {...props} />
            )}
          />
          <Controller
            {...control('bladeLength')}
            render={(props) => (
              <NumberField label={{ text: 'Blade length' }} {...props} />
            )}
          />
        </div>
        <div className={styles.buttonBox}>
          <Button variant="secondary" onClick={handleReset}>
            Reset
          </Button>
          <Button type="submit" pending={pending}>
            Submit
          </Button>
        </div>
      </form>
    </div>
  );
}
