import { deleteTurbineType, getTurbineTypes, TurbineType } from '@api/wind';
import { Button, Heading } from '@components/ui';
import { DataGrid } from '@components/ui/data-grid';
import { ROUTES, useRoute } from '@utils/route';
import React, { useEffect, useState } from 'react';
import { Link } from 'react-router-dom';

import { columns } from './constants';
import styles from './styles.module.scss';

export function TurbineTypesPage() {
  const [turbineTypes, setTurbineTypes] = useState<TurbineType[]>([]);
  const [selected, setSelected] = useState<TurbineType>(null);
  const route = useRoute();

  const fetchTurbineTypes = async () => {
    const res = await getTurbineTypes();
    setTurbineTypes(res.data ?? []);
  };

  useEffect(() => {
    fetchTurbineTypes();
  }, []);

  const handleTurbineTypeSelect = (items: TurbineType[]) => {
    setSelected(items[0] ?? null);
  };

  const handleDeleteButtonClick = async () => {
    await deleteTurbineType(selected.id);
    fetchTurbineTypes();
  };

  return (
    <div className={styles.page}>
      <Heading tag="h1">{route.title}</Heading>
      <div className={styles.actions}>
        <Link to={ROUTES.turbineType.path.replace(':id', 'new')}>
          <Button>Create new</Button>
        </Link>
        {selected && (
          <Link
            to={ROUTES.turbineType.path.replace(':id', String(selected.id))}
          >
            <Button variant="secondary">Edit</Button>
          </Link>
        )}
        {selected && (
          <Button variant="secondary" onClick={handleDeleteButtonClick}>
            Delete
          </Button>
        )}
      </div>
      <div className={styles.dataGridWrapper}>
        <DataGrid
          items={turbineTypes}
          columns={columns}
          getItemKey={({ id }) => String(id)}
          selectedItems={selected ? [selected] : []}
          onItemsSelect={handleTurbineTypeSelect}
          multiselect={false}
        />
      </div>
    </div>
  );
}
