import clsx from 'clsx';
import React, {
  CSSProperties,
  ForwardedRef,
  forwardRef,
  useEffect,
  useState,
} from 'react';

import styles from './styles.module.scss';
import { FadeProps } from './types';

export function FadeInner(
  {
    visible,
    duration = 200,
    className,
    style,
    ...props
  }: Omit<FadeProps, 'ref'>,
  ref: ForwardedRef<HTMLDivElement>,
) {
  const [visibleInternal, setVisibleInternal] = useState<boolean>(visible);

  const classNames = clsx(
    styles.fade,
    { [styles.invisible]: !visible },
    className,
  );

  const inlineStyle = {
    ...style,
    '--animation-duration': `${duration}ms`,
  } as CSSProperties;

  useEffect(() => {
    if (visible) {
      setVisibleInternal(true);
    }
  }, [visible]);

  const handleAnimationEnd = (event: React.AnimationEvent) => {
    if (event.animationName === styles.fadeout) {
      setVisibleInternal(false);
    }
  };

  if (!visibleInternal) {
    return null;
  }

  return (
    <div
      className={classNames}
      ref={ref}
      style={inlineStyle}
      onAnimationEnd={handleAnimationEnd}
      {...props}
    />
  );
}

export const Fade = forwardRef(FadeInner);
