import clsx from 'clsx';
import React, { useRef } from 'react';

import styles from './styles.module.scss';
import { calcRippleWaveStyle } from './utils';

export function Ripple() {
  const rippleRef = useRef<HTMLDivElement | null>(null);

  const clean = () => {
    document.removeEventListener('touchend', clean);
    document.removeEventListener('mouseup', clean);
    if (!rippleRef.current) {
      return;
    }
    const { lastChild: wave } = rippleRef.current;
    if (!wave || !(wave instanceof HTMLElement)) {
      return;
    }
    wave.dataset.isMouseReleased = 'true';
    if (wave.dataset.isAnimationComplete) {
      wave.classList.replace(styles.visible, styles.invisible);
    }
  };

  const handleAnimationEnd = (event: AnimationEvent) => {
    const { target: wave, animationName } = event;
    if (!(wave instanceof HTMLElement)) {
      return;
    }
    if (animationName === styles.fadein) {
      wave.dataset.isAnimationComplete = 'true';
      if (wave.dataset.isMouseReleased) {
        wave.classList.replace(styles.visible, styles.invisible);
      }
    } else {
      wave.remove();
    }
  };

  const addWave = (x: number, y: number) => {
    const wave = document.createElement('div');
    const style = calcRippleWaveStyle(x, y, rippleRef.current);
    Object.assign(wave.style, style);
    wave.className = clsx(styles.wave, styles.visible);
    wave.addEventListener('animationend', handleAnimationEnd);
    rippleRef.current.appendChild(wave);
    document.addEventListener('touchend', clean);
    document.addEventListener('mouseup', clean);
  };

  const handlePointerDown = (event: React.MouseEvent) => {
    event.stopPropagation();
    const { pageX, pageY } = event;
    addWave(pageX, pageY);
  };

  return (
    <div
      className={styles.ripple}
      ref={rippleRef}
      onPointerDown={handlePointerDown}
    />
  );
}
