import React, { ForwardedRef, forwardRef, useEffect, useState } from 'react';

import { CalendarDays } from './components';
import { CalendarProps } from './types';

function CalendarInner(
  { value, onChange, min, max, ...props }: Omit<CalendarProps, 'ref'>,
  ref: ForwardedRef<HTMLDivElement>,
) {
  const [date, setDate] = useState<Date>(value ? new Date(value) : new Date());

  useEffect(() => {
    setDate(value ? new Date(value) : new Date());
  }, [value]);

  const handleMonthChange = (delta: number) => {
    const newDate = new Date(date);
    newDate.setMonth(newDate.getMonth() + delta);
    setDate(newDate);
  };

  return (
    <div {...props} ref={ref}>
      <CalendarDays
        value={value}
        onChange={onChange}
        min={min}
        max={max}
        date={date}
        onMonthChange={handleMonthChange}
      />
    </div>
  );
}

export const Calendar = forwardRef(CalendarInner);
