import { CalendarDay, GetCalendarDaysParams } from './types';

const addDays = (date: Date, days: number) => {
  date.setDate(date.getDate() + days);
};

function dateToInputString(date: Date) {
  const year = date.getFullYear();
  const month = String(date.getMonth() + 1).padStart(2, '0');
  const day = String(date.getDate()).padStart(2, '0');
  const hours = String(date.getHours()).padStart(2, '0');
  const minutes = String(date.getMinutes()).padStart(2, '0');
  return `${year}-${month}-${day}T${hours}:${minutes}`;
}

const daysAreEqual = (date1: Date, date2: Date) => {
  return (
    date1.getDate() === date2.getDate() &&
    date1.getMonth() === date2.getMonth() &&
    date1.getFullYear() === date2.getFullYear()
  );
};

export const getCalendarDays = ({
  year,
  monthIndex,
  today,
  selectedDateStr,
  min,
  max,
}: GetCalendarDaysParams) => {
  const selectedDate = new Date(selectedDateStr);

  const firstDayOfMonth = new Date(year, monthIndex, 1);
  const daysFromPrevMonth = (firstDayOfMonth.getDay() || 7) - 1;

  const date = new Date(year, monthIndex, 1);
  addDays(date, -daysFromPrevMonth);
  const days: CalendarDay[] = [];

  for (let i = 0; i < 42; i += 1) {
    const number = date.getDate();
    const isDisabled = (min && date < min) || (max && date > max);
    const isSelected = daysAreEqual(date, selectedDate);
    const isToday = daysAreEqual(date, today);
    const string = dateToInputString(date);
    const isCurrentMonth = date.getMonth() === monthIndex;
    days.push({
      number,
      isDisabled,
      isSelected,
      isToday,
      string,
      isCurrentMonth,
    });
    addDays(date, 1);
  }
  return days;
};
