import clsx from 'clsx';
import React from 'react';

import { Checkbox } from '../checkbox';
import { Span } from '../span';
import styles from './styles.module.scss';
import { CheckboxGroupProps } from './types';

export function CheckboxGroup<T>({
  name,
  value,
  items,
  onChange,
  getItemKey,
  getItemLabel,
  scale = 'm',
  label,
}: CheckboxGroupProps<T>) {
  const classNames = clsx(styles.checkBoxGroup, styles[scale]);

  const handleChange = (index: number) => {
    onChange(value.with(index, !value[index]));
  };

  return (
    <div className={classNames}>
      <Span color="t300" scale={scale} className={styles.label}>
        {label}
      </Span>
      {items.map((item, index) => (
        <Checkbox
          name={name}
          label={{ text: getItemLabel(item) }}
          checked={value[index]}
          key={getItemKey(item)}
          onChange={() => handleChange(index)}
          scale={scale}
        />
      ))}
    </div>
  );
}
