import { Ripple } from '@components/ui/animation';
import { Checkbox } from '@components/ui/checkbox';
import { RawButton } from '@components/ui/raw';
import { Span } from '@components/ui/span';
import ArrowUpIcon from '@public/images/svg/arrow-up.svg';
import clsx from 'clsx';
import React, { useState } from 'react';

import { DataGridSort } from '../../types';
import styles from './styles.module.scss';
import { DataGridHeaderProps } from './types';

export function DataGridHeader<T>({
  columns,
  allItemsSelected,
  onSelectAllItems,
  columnsTemplate,
}: DataGridHeaderProps<T>) {
  const [sort, setSort] = useState<DataGridSort>({ order: 'asc', column: '' });

  const handleSortButtonClick = (column: string) => {
    if (column === sort.column) {
      if (sort.order === 'asc') {
        setSort({ order: 'desc', column });
      } else {
        setSort({ order: 'desc', column: '' });
      }
    } else {
      setSort({ order: 'asc', column });
    }
  };

  return (
    <header
      className={styles.header}
      style={{ gridTemplateColumns: columnsTemplate }}
    >
      <Checkbox
        checked={allItemsSelected}
        onChange={onSelectAllItems}
        label={{ className: styles.checkboxLabel }}
      />
      {columns.map((column) => {
        const isActive = sort.column === column.name;
        const cellClassName = clsx(styles.cell, {
          [styles.activeCell]: isActive,
          [styles.desc]: isActive && sort.order === 'desc',
        });
        return (
          <RawButton
            className={cellClassName}
            key={column.name}
            onClick={() => handleSortButtonClick(column.name)}
          >
            <Span color="t300" className={styles.name}>
              {column.name}
            </Span>
            <ArrowUpIcon className={styles.icon} />
            <Ripple />
          </RawButton>
        );
      })}
    </header>
  );
}
