import { PreviewArticle } from '@components/ui/preview';
import React, { useState } from 'react';

import { DataGrid } from './component';
import { DataGridColumnConfig } from './types';

type Cat = {
  name: string;
  breed: string;
  age: string;
  color: string;
};

export function DataGridPreview() {
  const [selectedItems, setSelectedItems] = useState<Cat[]>([]);

  const items: Cat[] = [
    { name: 'Luna', breed: 'British Shorthair', color: 'Gray', age: '2' },
    { name: 'Simba', breed: 'Siamese', color: 'Cream', age: '1' },
    { name: 'Bella', breed: 'Maine Coon', color: 'Brown Tabby', age: '3' },
    { name: 'Oliver', breed: 'Persian', color: 'White', age: '4' },
    { name: 'Milo', breed: 'Sphynx', color: 'Pink', age: '2' },
  ];

  const columns: DataGridColumnConfig<Cat>[] = [
    { name: 'Name', getText: (cat) => cat.name },
    { name: 'Breed', getText: (cat) => cat.breed, width: 2 },
    { name: 'Age', getText: (cat) => cat.age },
    { name: 'Color', getText: (cat) => cat.color },
  ];

  return (
    <PreviewArticle title="DataGrid">
      <div style={{ width: '100%', overflow: 'auto' }}>
        <DataGrid
          style={{ minWidth: 500 }}
          items={items}
          columns={columns}
          getItemKey={({ name }) => name}
          selectedItems={selectedItems}
          onItemsSelect={setSelectedItems}
        />
      </div>
    </PreviewArticle>
  );
}
