import { useMissClick } from '@utils/miss-click';
import clsx from 'clsx';
import React, { useRef } from 'react';

import { Fade } from '../animation';
import { Heading } from '../heading';
import { Overlay } from '../overlay';
import { Paragraph } from '../paragraph';
import styles from './styles.module.scss';
import { DialogProps } from './types';

export function Dialog({
  open,
  onClose,
  heading,
  message,
  triggerElementRef,
  className,
  children,
  ...props
}: DialogProps) {
  const dialogRef = useRef<HTMLDivElement>(null);

  useMissClick({
    callback: onClose,
    enabled: open,
    whitelist: [dialogRef, triggerElementRef],
  });

  const dialogClassName = clsx(styles.dialog, className);

  return (
    <Overlay open={open} className={styles.overlay}>
      <Fade visible={open} className={styles.fade}>
        <div className={dialogClassName} ref={dialogRef} {...props}>
          <Heading tag="h3">{heading}</Heading>
          <Paragraph color="t300">{message}</Paragraph>
          {children}
        </div>
      </Fade>
    </Overlay>
  );
}
