import UploadIcon from '@public/images/svg/upload.svg';
import { getFileExtension } from '@utils/file';
import clsx from 'clsx';
import React, { useRef } from 'react';

import { Ripple } from '../animation';
import { Label } from '../label';
import { RawButton, RawInput } from '../raw';
import { Span } from '../span';
import styles from './style.module.scss';
import { FileUploaderProps } from './types';

export function FileUploader({
  extensions,
  onChange,
  scale = 'm',
  label = {},
  input = {},
  ...props
}: FileUploaderProps) {
  const inputRef = useRef<HTMLInputElement | null>(null);
  const uploaderClassName = clsx(styles.uploader, styles[scale]);

  const handleChange = (files: FileList) => {
    if (!files || !onChange) {
      return;
    }
    const array = Array.from(files);
    const filtered = extensions
      ? array.filter((file) => extensions.includes(getFileExtension(file)))
      : array;
    onChange(filtered);
  };

  const handleButtonClick = () => {
    inputRef.current.click();
  };

  const handleInputChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    handleChange(event.target.files);
  };

  const handleDragOver = (event: React.DragEvent) => {
    event.preventDefault();
    event.dataTransfer.dropEffect = 'copy';
  };

  const handleDrop = (event: React.DragEvent) => {
    event.preventDefault();
    handleChange(event.dataTransfer.files);
  };

  return (
    <Label scale={scale} {...label}>
      <RawButton
        className={uploaderClassName}
        onClick={handleButtonClick}
        onDragOver={handleDragOver}
        onDrop={handleDrop}
        {...props}
      >
        <UploadIcon className={styles.icon} />
        <Span color="t300" scale={scale}>
          Drag and drop file here or click to upload
        </Span>
        <RawInput
          type="file"
          className={styles.input}
          ref={inputRef}
          onChange={handleInputChange}
          accept={extensions && extensions.map((ext) => `.${ext}`).join(',')}
          {...input}
        />
        <Ripple />
      </RawButton>
    </Label>
  );
}
