import clsx from 'clsx';
import React from 'react';

import { FileUploader } from '../file-uploader';
import { ImageViewer } from '../image-viewer';
import styles from './styles.module.scss';
import { ImageFileManagerProps } from './types';

export function ImageFileManager({
  value,
  onChange,
  scale = 'm',
  label = {},
}: ImageFileManagerProps) {
  const managerClassName = clsx(styles.manager, styles[scale]);

  const handleFileUploaderChange = (files: File[]) => {
    const file = files[0];
    if (!file) {
      return;
    }
    onChange?.(file);
  };

  const handleClear = () => {
    onChange?.(null);
  };

  return (
    <div className={managerClassName}>
      <FileUploader
        scale={scale}
        label={label}
        onChange={handleFileUploaderChange}
        extensions={['png', 'jpg', 'jpeg']}
      />
      <ImageViewer file={value} scale={scale} onClear={handleClear} />
    </div>
  );
}
