import DeleteIcon from '@public/images/svg/delete.svg';
import { formatFileSize } from '@utils/file';
import clsx from 'clsx';
import React from 'react';

import { IconButton } from '../icon-button';
import { Span } from '../span';
import styles from './styles.module.scss';
import { ImageViewerProps } from './types';

export function ImageViewer({ file, scale = 'm', onClear }: ImageViewerProps) {
  const viewerClassName = clsx(styles.viewer, styles[scale]);
  return (
    <div className={viewerClassName}>
      {file ? (
        <>
          <img className={styles.image} src={URL.createObjectURL(file)} />
          <footer className={styles.footer}>
            <Span scale={scale}>{formatFileSize(file.size)}</Span>
            <IconButton scale={scale} onClick={onClear}>
              <DeleteIcon />
            </IconButton>
          </footer>
        </>
      ) : (
        <div className={styles.placeholder}>
          <Span scale={scale}>File not uploaded</Span>
        </div>
      )}
    </div>
  );
}
