import clsx from 'clsx';
import React, { ForwardedRef, forwardRef, useState } from 'react';

import { RawInput } from '../raw';
import styles from './styles.module.scss';
import { InputProps } from './types';

function InputInner(
  {
    scale = 'm',
    wrapper = {},
    leftNode,
    rightNode,
    invalid,
    className,
    onFocus,
    onBlur,
    ...props
  }: Omit<InputProps, 'ref'>,
  ref: ForwardedRef<HTMLInputElement>,
) {
  const [focus, setFocus] = useState<boolean>(false);
  const wrapperClassNames = clsx(
    styles[scale],
    styles.wrapper,
    focus && styles.wrapperFocus,
    wrapper.className,
    invalid && styles.invalid,
  );
  const inputClassNames = clsx(styles.input, className);

  const handleFocus = (event: React.FocusEvent<HTMLInputElement>) => {
    onFocus?.(event);
    setFocus(true);
  };

  const handleBlur = (event: React.FocusEvent<HTMLInputElement>) => {
    onBlur?.(event);
    setFocus(false);
  };

  return (
    <div {...wrapper} className={wrapperClassNames}>
      {leftNode}
      <RawInput
        className={inputClassNames}
        onFocus={handleFocus}
        onBlur={handleBlur}
        ref={ref}
        {...props}
      />
      {rightNode}
    </div>
  );
}

export const Input = forwardRef(InputInner);
