import clsx from 'clsx';
import React, { ForwardedRef, forwardRef } from 'react';

import { Span } from '../span';
import styles from './styles.module.scss';
import { LabelProps } from './types';

function LabelInner(
  {
    text,
    scale,
    position = 'top',
    required = {},
    error,
    className,
    children,
    ...props
  }: Omit<LabelProps, 'ref'>,
  ref: ForwardedRef<HTMLLabelElement>,
) {
  const classNames = clsx(styles.label, styles[position], className);
  const reversed = position === 'right' || position === 'bottom';
  return (
    <label className={classNames} ref={ref} {...props}>
      {reversed && children}
      {text && (
        <Span scale={scale} color="t300">
          {text}
          {required.value && ` ${required.text ?? '*'}`}
        </Span>
      )}
      {!reversed && children}
      {error && (
        <Span scale={scale} className={styles.error}>
          {error}
        </Span>
      )}
    </label>
  );
}

export const Label = forwardRef(LabelInner);
