import CheckIcon from '@public/images/svg/check.svg';
import clsx from 'clsx';
import React, { ForwardedRef, forwardRef } from 'react';

import { Ripple } from '../animation';
import { RawButton } from '../raw';
import styles from './styles.module.scss';
import { MenuProps } from './types';

function MenuInner<T>(
  {
    options,
    selected,
    getOptionKey,
    getOptionLabel,
    onSelect,
    className,
    ...props
  }: Omit<MenuProps<T>, 'ref'>,
  ref: ForwardedRef<HTMLUListElement>,
) {
  const handleButtonClick = (option: T) => {
    onSelect?.(option);
  };

  return (
    <ul className={clsx(className, styles.menu)} ref={ref} {...props}>
      {options.map((option) => {
        const isSelected =
          selected && getOptionKey(option) === getOptionKey(selected);
        const className = clsx(styles.button, {
          [styles.selected]: isSelected,
        });
        return (
          <li key={getOptionKey(option)}>
            <RawButton
              onClick={() => handleButtonClick(option)}
              className={className}
            >
              {getOptionLabel(option)}
              {isSelected && <CheckIcon className={styles.icon} />}
              <Ripple />
            </RawButton>
          </li>
        );
      })}
    </ul>
  );
}

export const Menu = forwardRef(MenuInner);
