import React from 'react';

import { Input } from '../input';
import { NumberInputProps } from './types';

export function NumberInput({
  value,
  onChange,
  float = false,
  negative = false,
  ...props
}: NumberInputProps) {
  const extractNumber = (event: React.ChangeEvent<HTMLInputElement>) => {
    const { value } = event.target;
    if (!value) {
      return '';
    }
    let pattern = '';
    if (negative) {
      pattern += '-?';
    }
    pattern += '\\d*';
    if (float) {
      pattern += '\\.?\\d*';
    }
    return value.match(pattern)?.[0] ?? null;
  };

  const handleChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    const num = extractNumber(event);
    if (num === null) {
      return;
    }
    onChange?.(num);
  };

  return <Input value={value ?? ''} onChange={handleChange} {...props} />;
}
