import clsx from 'clsx';
import React, { ForwardedRef, forwardRef, useEffect, useState } from 'react';
import { createPortal } from 'react-dom';

import styles from './styles.module.scss';
import { OverlayProps } from './types';

function OverlayInner(
  { open, className, ...props }: OverlayProps,
  ref: ForwardedRef<HTMLDivElement>,
) {
  const [openInternal, setOpenInternal] = useState<boolean>(open);

  useEffect(() => {
    if (open) {
      setOpenInternal(true);
    }
  }, [open]);

  const overlayClassName = clsx(
    styles.overlay,
    { [styles.closed]: !open },
    className,
  );

  const handleAnimationEnd = (event: React.AnimationEvent) => {
    if (event.animationName === styles.fadeout) {
      setOpenInternal(false);
    }
  };

  if (!openInternal) {
    return null;
  }

  return createPortal(
    <div
      className={overlayClassName}
      onAnimationEnd={handleAnimationEnd}
      ref={ref}
      {...props}
    />,
    document.body,
  );
}

export const Overlay = forwardRef(OverlayInner);
