import ArrowLeftIcon from '@public/images/svg/arrow-left.svg';
import ArrowRightIcon from '@public/images/svg/arrow-right.svg';
import clsx from 'clsx';
import React from 'react';

import { PaginationItem } from './components';
import styles from './styles.module.scss';
import { PaginationProps } from './types';
import { getPageNumbers } from './utils';

export function Pagination({
  value,
  onChange,
  total,
  sibling = 2,
  boundary = 1,
  scale = 'm',
}: PaginationProps) {
  const pageNumbers = getPageNumbers(value, total, sibling, boundary);
  const paginationClassNames = clsx(styles.pagination, styles[scale]);

  const handleBackButtonClick = () => {
    onChange?.(Math.max(value - 1, 1));
  };

  const handleNextButtonClick = () => {
    onChange?.(Math.min(value + 1, total));
  };

  return (
    <div className={paginationClassNames}>
      <PaginationItem
        scale={scale}
        variant="default"
        onClick={handleBackButtonClick}
        disabled={value === 1}
      >
        <ArrowLeftIcon className={styles.icon} />
      </PaginationItem>
      {pageNumbers.map((number, index) => {
        if (number === null) {
          return (
            <PaginationItem scale={scale} variant="dots" disabled key={index}>
              ...
            </PaginationItem>
          );
        }
        const isCurrent = number === value;
        return (
          <PaginationItem
            scale={scale}
            variant={isCurrent ? 'current' : 'default'}
            disabled={isCurrent}
            key={index}
            onClick={() => onChange?.(number)}
          >
            {number}
          </PaginationItem>
        );
      })}
      <PaginationItem
        scale={scale}
        variant="default"
        onClick={handleNextButtonClick}
        disabled={value === total}
      >
        <ArrowRightIcon className={styles.icon} />
      </PaginationItem>
    </div>
  );
}
