import HideIcon from '@public/images/svg/hide.svg';
import ShowIcon from '@public/images/svg/show.svg';
import React, { ForwardedRef, forwardRef, useState } from 'react';

import { IconButton } from '../icon-button';
import { TextInput } from '../text-input';
import { PasswordInputProps } from './types';

function PasswordInputInner(
  { rightNode, scale, ...props }: Omit<PasswordInputProps, 'ref'>,
  ref: ForwardedRef<HTMLInputElement>,
) {
  const [visible, setVisible] = useState<boolean>(false);

  const handleShowButtonClick = () => {
    setVisible(!visible);
  };

  const handleShowButtonMouseDown = (event: React.MouseEvent) => {
    event.preventDefault();
  };

  const handleShowButtonMouseUp = (event: React.MouseEvent) => {
    event.preventDefault();
  };

  return (
    <TextInput
      type={visible ? 'text' : 'password'}
      scale={scale}
      rightNode={
        <>
          <IconButton
            scale={scale}
            onClick={handleShowButtonClick}
            onMouseDown={handleShowButtonMouseDown}
            onMouseUp={handleShowButtonMouseUp}
          >
            {visible ? <HideIcon /> : <ShowIcon />}
          </IconButton>
          {rightNode}
        </>
      }
      ref={ref}
      {...props}
    />
  );
}

export const PasswordInput = forwardRef(PasswordInputInner);
