import React, {
  cloneElement,
  useEffect,
  useLayoutEffect,
  useRef,
  useState,
} from 'react';
import { createPortal } from 'react-dom';

import { Fade } from '../animation';
import styles from './styles.module.scss';
import { PopoverProps } from './types';
import { calcFadeStyles } from './utils';

export function Popover({
  visible,
  anchorRef,
  position,
  horizontalAlign,
  element,
  flip = false,
}: PopoverProps) {
  const elementRef = useRef<HTMLElement | null>(null);
  const fadeRef = useRef<HTMLDivElement | null>(null);
  const [elementRect, setElementRect] = useState<DOMRect | null>(null);

  useLayoutEffect(() => {
    setElementRect(elementRef.current.getBoundingClientRect());
  }, []);

  useEffect(() => {
    if (!visible) {
      return;
    }
    const updateStyles = () => {
      const style = calcFadeStyles(
        elementRect,
        anchorRef,
        position,
        horizontalAlign,
        flip,
      );
      Object.assign(fadeRef.current.style, style);
    };
    window.addEventListener('scroll', updateStyles, true);
    window.addEventListener('resize', updateStyles);
    return () => {
      window.removeEventListener('scroll', updateStyles, true);
      window.removeEventListener('resize', updateStyles);
    };
  }, [visible]);

  if (elementRect === null) {
    return cloneElement(element, {
      ref: elementRef,
      style: { position: 'absolute' },
    });
  }

  return createPortal(
    <Fade
      visible={visible}
      className={styles.fade}
      ref={fadeRef}
      style={calcFadeStyles(
        elementRect,
        anchorRef,
        position,
        horizontalAlign,
        flip,
      )}
    >
      {element}
    </Fade>,
    document.body,
  );
}
