import { px } from '@utils/css';
import { CSSProperties, MutableRefObject } from 'react';

import { PopoverHorizontalAlign, PopoverPosition } from './types';

const applyPositionTop = (
  anchorRect: DOMRect,
  elementRect: DOMRect,
  styles: CSSProperties,
) => {
  styles.top = px(anchorRect.bottom - anchorRect.height - elementRect.height);
};

const applyPositionBottom = (anchorRect: DOMRect, styles: CSSProperties) => {
  styles.top = px(anchorRect.bottom);
};

const applyPosition = (
  elementRect: DOMRect,
  anchorRect: DOMRect,
  position: PopoverPosition,
  flip: boolean,
  styles: CSSProperties,
) => {
  if (position === 'bottom') {
    if (flip) {
      const bottomSpace = window.innerHeight - anchorRect.bottom;
      if (bottomSpace >= elementRect.height) {
        applyPositionBottom(anchorRect, styles);
      } else {
        applyPositionTop(anchorRect, elementRect, styles);
      }
    } else {
      applyPositionBottom(anchorRect, styles);
    }
  }

  if (position === 'top') {
    if (flip) {
      const topSpace = anchorRect.top;
      if (topSpace >= elementRect.height) {
        applyPositionTop(anchorRect, elementRect, styles);
      } else {
        applyPositionBottom(anchorRect, styles);
      }
    } else {
      applyPositionTop(anchorRect, elementRect, styles);
    }
  }
};

const applyHorizontalAlign = (
  elementRect: DOMRect,
  anchorRect: DOMRect,
  horizontalAlign: PopoverHorizontalAlign,
  styles: CSSProperties,
) => {
  if (horizontalAlign === 'left') {
    styles.left = px(anchorRect.left);
  }

  if (horizontalAlign === 'right') {
    styles.left = px(anchorRect.left + anchorRect.width - elementRect.width);
  }

  if (horizontalAlign === 'center') {
    styles.left = px(
      anchorRect.left + (anchorRect.width - elementRect.width) / 2,
    );
  }

  if (horizontalAlign === 'stretch') {
    styles.left = px(anchorRect.left);
    styles.width = px(anchorRect.width);
  }
};

export const calcFadeStyles = (
  elementRect: DOMRect,
  anchorRef: MutableRefObject<HTMLElement>,
  position: PopoverPosition,
  horizontalAlign: PopoverHorizontalAlign,
  flip: boolean,
): CSSProperties => {
  const anchorRect = anchorRef.current.getBoundingClientRect();
  const styles: CSSProperties = {};

  applyPosition(elementRect, anchorRect, position, flip, styles);
  applyHorizontalAlign(elementRect, anchorRect, horizontalAlign, styles);

  return styles;
};
