import clsx from 'clsx';
import React from 'react';

import { Radio } from '../radio';
import { Span } from '../span';
import styles from './styles.module.scss';
import { RadioGroupProps } from './types';

export function RadioGroup<T>({
  name,
  value,
  items,
  onChange,
  getItemKey,
  getItemLabel,
  scale = 'm',
  label,
}: RadioGroupProps<T>) {
  const classNames = clsx(styles.checkBoxGroup, styles[scale]);

  const handleChange = (item: T) => {
    onChange(item);
  };

  return (
    <div className={classNames}>
      <Span color="t300" scale={scale} className={styles.label}>
        {label}
      </Span>
      {items.map((item) => (
        <Radio
          name={name}
          label={{ text: getItemLabel(item) }}
          checked={value && getItemKey(item) === getItemKey(value)}
          key={getItemKey(item)}
          onChange={() => handleChange(item)}
          scale={scale}
        />
      ))}
    </div>
  );
}
