import RadioIcon from '@public/images/svg/radio.svg';
import clsx from 'clsx';
import React, { ForwardedRef, forwardRef } from 'react';

import { Ripple } from '../animation';
import { Label, LabelProps } from '../label';
import { RawInput } from '../raw';
import styles from './styles.module.scss';
import { RadioProps } from './types';

function RadioInner(
  {
    scale = 'm',
    label = {},
    required,
    checked,
    ...props
  }: Omit<RadioProps, 'ref'>,
  ref: ForwardedRef<HTMLInputElement>,
) {
  const wrapperClassName = clsx(styles.wrapper, styles[scale], {
    [styles.checked]: checked,
  });

  const labelProps: LabelProps = {
    position: 'right',
    scale: scale,
    ...label,
    required: { value: required, ...label.required },
  };

  return (
    <Label {...labelProps}>
      <div className={wrapperClassName}>
        <RawInput
          className={styles.input}
          type="radio"
          ref={ref}
          required={required}
          checked={checked}
          {...props}
        />
        <div className={styles.radio}>
          <RadioIcon className={styles.icon} />
        </div>
        <Ripple />
      </div>
    </Label>
  );
}

export const Radio = forwardRef(RadioInner);
