import ArrowDownIcon from '@public/images/svg/arrow-down.svg';
import { useMissClick } from '@utils/miss-click';
import clsx from 'clsx';
import React, {
  ForwardedRef,
  forwardRef,
  useImperativeHandle,
  useRef,
  useState,
} from 'react';

import { Menu } from '../menu';
import { Popover } from '../popover';
import { TextInput } from '../text-input';
import styles from './styles.module.scss';
import { SelectProps } from './types';

function SelectInner<T>(
  {
    options,
    value,
    getOptionKey,
    getOptionLabel,
    onChange,
    scale = 'm',
    label = {},
    name,
    id,
  }: Omit<SelectProps<T>, 'ref'>,
  ref: ForwardedRef<HTMLDivElement>,
) {
  const selectRef = useRef<HTMLDivElement | null>(null);
  const menuRef = useRef<HTMLUListElement | null>(null);
  const inputWrapperRef = useRef<HTMLDivElement | null>(null);
  const [menuVisible, setMenuVisible] = useState<boolean>(false);

  useImperativeHandle(ref, () => selectRef.current, []);

  useMissClick({
    callback: () => setMenuVisible(false),
    enabled: menuVisible,
    whitelist: [selectRef, menuRef],
  });

  const selectClassName = clsx(styles.select, styles[scale], {
    [styles.menuVisible]: menuVisible,
  });

  const handleInputClick = () => {
    setMenuVisible(!menuVisible);
  };

  const handleMenuSelect = (option: T) => {
    setMenuVisible(false);
    onChange?.(option);
  };

  return (
    <div className={selectClassName} ref={selectRef}>
      <TextInput
        value={value ? getOptionLabel(value) : ''}
        readOnly
        onClick={handleInputClick}
        scale={scale}
        label={label}
        name={name}
        id={id}
        wrapper={{ ref: inputWrapperRef }}
        rightNode={
          <div className={styles.iconBox}>
            <ArrowDownIcon className={styles.icon} />
          </div>
        }
      />
      <Popover
        visible={menuVisible}
        anchorRef={selectRef}
        position="bottom"
        horizontalAlign="stretch"
        flip
        element={
          <div className={styles.menuWrapper}>
            <Menu
              options={options}
              selected={value}
              getOptionKey={getOptionKey}
              getOptionLabel={getOptionLabel}
              onSelect={handleMenuSelect}
              ref={menuRef}
            />
          </div>
        }
      />
    </div>
  );
}

export const Select = forwardRef(SelectInner) as <T>(
  props: SelectProps<T>,
) => ReturnType<typeof SelectInner>;
