import { Heading, IconButton } from '@components/ui';
import MenuIcon from '@public/images/svg/menu.svg';
import clsx from 'clsx';
import React, { useRef, useState } from 'react';

import { MobileSidebar } from '../mobile-sidebar';
import styles from './styles.module.scss';
import { HeaderProps } from './types';

export function Header({ className, ...props }: HeaderProps) {
  const openButtonRef = useRef<HTMLButtonElement>(null);
  const [open, setOpen] = useState<boolean>(false);

  const headerClassName = clsx(styles.header, className);

  return (
    <header className={headerClassName} {...props}>
      <IconButton
        onClick={() => setOpen(true)}
        variant="rect"
        ref={openButtonRef}
      >
        <MenuIcon className={styles.icon} />
      </IconButton>
      <Heading tag="h3">Wind</Heading>
      <MobileSidebar
        open={open}
        onClose={() => setOpen(false)}
        openButtonRef={openButtonRef}
      />
    </header>
  );
}
