import { Heading, IconButton, Overlay } from '@components/ui';
import CloseIcon from '@public/images/svg/close.svg';
import { useMissClick } from '@utils/miss-click';
import clsx from 'clsx';
import React, { useRef } from 'react';

import { Navigation } from '../navigation';
import { ThemeSelect } from '../theme-select';
import styles from './styles.module.scss';
import { MobileSidebarProps } from './types';

export function MobileSidebar({
  open,
  onClose,
  openButtonRef,
}: MobileSidebarProps) {
  const overlayRef = useRef<HTMLDivElement>(null);
  const sidebarRef = useRef<HTMLDivElement>(null);
  const sidebarClassName = clsx(styles.sidebar, { [styles.closed]: !open });

  useMissClick({
    callback: onClose,
    enabled: open,
    whitelist: [sidebarRef, openButtonRef],
    blacklist: [overlayRef],
  });

  return (
    <Overlay className={styles.overlay} open={open} ref={overlayRef}>
      <div className={sidebarClassName} ref={sidebarRef}>
        <div className={styles.header}>
          <IconButton onClick={onClose} variant="rect">
            <CloseIcon className={styles.icon} />
          </IconButton>
          <Heading tag="h3">Wind</Heading>
        </div>
        <ThemeSelect />
        <Navigation />
      </div>
    </Overlay>
  );
}
