import { getTurbineTypes, TurbineType } from '@api/wind';
import { ParkFormTurbine } from '@components/pages/park-page/types';
import { Autocomplete, Button } from '@components/ui';
import React, { useEffect, useState } from 'react';

import { ParkTurbineTable } from '../park-turbine-table';
import styles from './styles.module.scss';
import { ParkTurbinesProps } from './types';

export function ParkTurbines({
  savedTurbines,
  value = [],
  onChange,
}: ParkTurbinesProps) {
  const [turbineTypes, setTurbineTypes] = useState<TurbineType[]>([]);
  const [turbineType, setTurbineType] = useState<TurbineType>(null);
  const [selectedIDs, setSelectedIDs] = useState<Record<number, boolean>>({});

  const fetchTurbineTypes = async () => {
    const res = await getTurbineTypes();
    setTurbineTypes(res.data ?? []);
  };

  useEffect(() => {
    fetchTurbineTypes();
  }, []);

  const handleAddButtonClick = () => {
    if (
      savedTurbines.find((t) => t.id === turbineType.id) ||
      value.find((t) => t.id === turbineType.id)
    ) {
      return;
    }
    onChange([
      ...value,
      {
        id: turbineType.id,
        name: turbineType.name,
        xOffset: '',
        yOffset: '',
        angle: '',
        comment: '',
        new: true,
      },
    ]);
  };

  const handleDeleteButtonClick = () => {
    const newValue: ParkFormTurbine[] = [];
    value.forEach((turbine) => {
      if (!selectedIDs[turbine.id]) {
        newValue.push(turbine);
        return;
      }
      if (savedTurbines.find((t) => t.id === turbine.id)) {
        newValue.push({ ...turbine, delete: true });
      }
    });
    onChange(newValue);
    setSelectedIDs({});
  };

  return (
    <div className={styles.parkTurbines}>
      <div className={styles.actions}>
        <Autocomplete
          options={turbineTypes ?? []}
          getOptionKey={({ id }) => id}
          getOptionLabel={({ name }) => name}
          onChange={(t) => setTurbineType(t)}
          value={turbineType}
        />
        <Button onClick={handleAddButtonClick}>Add</Button>
        <Button variant="secondary" onClick={handleDeleteButtonClick}>
          Delete
        </Button>
      </div>
      <ParkTurbineTable
        turbines={value.filter((t) => !t.delete)}
        onChange={onChange}
        selectedIDs={selectedIDs}
        onSelect={setSelectedIDs}
      />
    </div>
  );
}
