import { arrayToObject } from '@utils/array';
import { STORAGE_KEYS } from '@utils/storage';

import { DEFAULT_THEME, THEMES } from './constants';
import { ColorTheme } from './types';

const themeMap = arrayToObject(THEMES, (t) => t.key);

export const setHTMLColorTheme = (theme: ColorTheme) => {
  document.documentElement.dataset['theme'] = theme.key;
};

export const getColorTheme = (): ColorTheme => {
  const storageTheme = localStorage.getItem(STORAGE_KEYS.colorTheme);
  if (!storageTheme || !themeMap[storageTheme]) {
    return null;
  }
  return themeMap[storageTheme];
};

export const setColorTheme = (theme: ColorTheme) => {
  localStorage.setItem(STORAGE_KEYS.colorTheme, theme.key);
  setHTMLColorTheme(theme);
};

export const initializeColorTheme = () => {
  const theme = getColorTheme();
  if (!theme) {
    setColorTheme(DEFAULT_THEME);
  } else {
    setHTMLColorTheme(theme);
  }
};
