import { useLayoutEffect, useState } from 'react';

import { DeviceType } from './types';

const defineDeviceType = (): DeviceType => {
  const width = window.innerWidth;
  if (width <= 800) {
    return 'mobile';
  }
  return 'desktop';
};

export const useDeviceType = () => {
  const [deviceType, setDeviceType] = useState<DeviceType>(defineDeviceType());

  const handleResize = () => {
    setDeviceType(defineDeviceType());
  };

  useLayoutEffect(() => {
    window.addEventListener('resize', handleResize);
    return () => {
      window.removeEventListener('resize', handleResize);
    };
  }, []);

  return deviceType;
};
