import { useCallback } from 'react';

import { RegistredElement, UseRegisterParams } from './types';
import { getInputValue, setInputValue } from './util';

export const useRegister = <T extends object>({
  storeRef,
}: UseRegisterParams<T>) => {
  return useCallback(
    <E extends RegistredElement, K extends keyof T>(name: K) => {
      const ref = (element: E) => {
        const value = storeRef.current.values[name];
        setInputValue(element, value);
      };
      const onChange = (event: React.ChangeEvent<E>) => {
        const value = getInputValue(event.target) as T[K];
        storeRef.current.values[name] = value;
      };
      return { name, ref, onChange };
    },
    [],
  );
};
