import { useRef } from 'react';

import { useControl } from '../control';
import { useGetValues } from '../get-values';
import { useRegister } from '../register';
import { useReset } from '../reset/hook';
import { FormStore } from '../types';
import { UseFormParams } from './types';

export const useForm = <T extends object>({
  initialValues = {},
}: UseFormParams<T>) => {
  const storeRef = useRef<FormStore<T>>({
    values: { ...initialValues },
    hash: 0,
  });

  const register = useRegister({ storeRef });

  const control = useControl({ storeRef });

  const getValues = useGetValues({ storeRef });

  const reset = useReset({ storeRef });

  return { register, control, getValues, reset };
};
