import { useEffect } from 'react';

import { UseMissClickParams } from './types';

export const useMissClick = ({
  callback,
  enabled,
  blacklist,
  whitelist,
}: UseMissClickParams) => {
  const handleClick = (event: MouseEvent) => {
    const { target } = event;
    if (!(target instanceof Element)) {
      return;
    }
    for (let i = 0; i < whitelist.length; i += 1) {
      if (whitelist[i]?.current?.contains(target)) {
        return;
      }
    }
    if (!blacklist) {
      callback();
      return;
    }
    for (let i = 0; i < blacklist.length; i += 1) {
      if (blacklist[i]?.current?.contains(target)) {
        callback();
      }
    }
  };

  useEffect(() => {
    if (!enabled) {
      return;
    }
    window.addEventListener('click', handleClick);
    return () => {
      window.removeEventListener('click', handleClick);
    };
  }, [enabled]);
};
