from datetime import datetime

from sqlalchemy import Integer, ForeignKey, String, Float
from sqlalchemy.orm import Mapped, mapped_column, DeclarativeBase, relationship
from sqlalchemy.dialects.mysql import TIMESTAMP, TIME, VARCHAR


class Base(DeclarativeBase):
    pass


class Weather(Base):
    __tablename__ = "weather_data"

    id: Mapped[int] = mapped_column(primary_key=True)
    BarTrend: Mapped[str] = mapped_column(VARCHAR(255))
    CRC: Mapped[str] = mapped_column(VARCHAR(255))
    DateStamp: Mapped[datetime] = mapped_column(TIMESTAMP)
    DewPoint: Mapped[float]
    HeatIndex: Mapped[float]
    ETDay: Mapped[float]
    HumIn: Mapped[float]
    HumOut: Mapped[float]
    Pressure: Mapped[float]
    RainDay: Mapped[float]
    RainMonth: Mapped[float]
    RainRate: Mapped[float]
    RainStorm: Mapped[float]
    RainYear: Mapped[float]
    SunRise: Mapped[datetime] = mapped_column(TIME)
    SunSet: Mapped[datetime] = mapped_column(TIME)
    TempIn: Mapped[float]
    TempOut: Mapped[float]
    WindDir: Mapped[str] = mapped_column(VARCHAR(50))
    WindSpeed: Mapped[float]
    WindSpeed10Min: Mapped[float]


class WindTurbineType(Base):
    __tablename__ = 'wind_turbine_type'
    Id: Mapped[int] = mapped_column(primary_key=True)
    Name: Mapped[str] = mapped_column(VARCHAR(255))
    Height: Mapped[float] = mapped_column(Float)
    BladeLength: Mapped[float] = mapped_column(Float)

    # Связь с WindParkTurbine
    turbine_parks: Mapped["list[WindParkTurbine]"] = relationship("WindParkTurbine", back_populates="turbine")


class WindPark(Base):
    __tablename__ = 'wind_park'
    Id: Mapped[int] = mapped_column(primary_key=True)
    Name: Mapped[str] = mapped_column(VARCHAR(255))
    CenterLatitude: Mapped[float] = mapped_column(Float)
    CenterLongitude: Mapped[float] = mapped_column(Float)

    # Связь с WindParkTurbine
    wind_park_turbines: Mapped["list[WindParkTurbine]"] = relationship("WindParkTurbine", back_populates="wind_park")


class WindParkTurbine(Base):
    __tablename__ = 'wind_park_turbine'

    wind_park_id: Mapped[int] = mapped_column(Integer, ForeignKey('wind_park.Id'), primary_key=True)
    turbine_id: Mapped[int] = mapped_column(Integer, ForeignKey('wind_turbine_type.Id'), primary_key=True)
    x_offset: Mapped[int] = mapped_column(Integer, nullable=False)
    y_offset: Mapped[int] = mapped_column(Integer, nullable=False)
    angle: Mapped[int] = mapped_column(Integer, nullable=True)
    comment: Mapped[str] = mapped_column(String(2000), nullable=True)

    # Связи с другими таблицами
    wind_park: Mapped[WindPark] = relationship("WindPark", back_populates="wind_park_turbines")
    turbine: Mapped[WindTurbineType] = relationship("WindTurbineType", back_populates="turbine_parks")
