from datetime import date
from typing import Optional

from pydantic import BaseModel, Field
from fastapi import Query


class SWeatherInfo(BaseModel):
    id: int
    WindDir: str
    WindSpeed: float


class SFlorisInputParams(BaseModel):
    layout_x: list[float] = Field(Query([]))
    layout_y: list[float] = Field(Query([]))
    yaw_angle: list[float] = Field(Query([]))
    plots: set[str] = Field(Query(["horizontal_plane"]))
    date_start: date
    date_end: date


class SFlorisOutputData(BaseModel):
    file_name: object
    data: object


class WindTurbineTypeBase(BaseModel):
    Name: str
    Height: float
    BladeLength: float


class WindTurbineTypeCreate(WindTurbineTypeBase):
    pass


class WindTurbineTypeResponse(WindTurbineTypeBase):
    Id: int

    class Config:
        orm_mode = True


class WindParkBase(BaseModel):
    Name: str
    CenterLatitude: float
    CenterLongitude: float


class WindParkCreate(WindParkBase):
    pass


class WindParkTurbineBase(BaseModel):
    wind_park_id: int
    turbine_id: int
    x_offset: int
    y_offset: int
    angle: Optional[int] = None
    comment: Optional[str] = None


class WindParkTurbineCreate(WindParkTurbineBase):
    pass


class WindParkTurbineResponse(WindParkTurbineBase):
    class Config:
        orm_mode = True


class WindTurbineType(BaseModel):
    Id: int
    Name: str
    Height: float
    BladeLength: float

    class Config:
        orm_mode = True


class WindParkResponse(BaseModel):
    Id: int
    Name: str
    CenterLatitude: float
    CenterLongitude: float

    class Config:
        orm_mode = True


class WindTurbineResponse(BaseModel):
    Id: int
    Name: str
    Height: float
    BladeLength: float

    class Config:
        orm_mode = True

class WindTurbineWithParkDetailsResponse(BaseModel):
    Id: int
    Name: str
    Height: float
    BladeLength: float
    x_offset: int
    y_offset: int
    angle: Optional[int]
    comment: Optional[str]

    class Config:
        orm_mode = True
