import sys

from pathlib import Path

from fastapi import FastAPI

from fastapi.staticfiles import StaticFiles

from routers.wind_park_router import router as wind_park_router
from routers.floris_router import router as floris_router
from routers.floris_template_router import router as floris_template_router
from routers.weather_router import router as weather_router
from fastapi.middleware.cors import CORSMiddleware


app = FastAPI()

origins = [
    "http://localhost:5000",
    "*"
]

app.add_middleware(
    CORSMiddleware,
    allow_origins=origins,
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

app.mount("/static", StaticFiles(directory=Path("../static")), name="static")
app.mount("/public", StaticFiles(directory=Path("../public")), name="public")

app.include_router(floris_router)
app.include_router(floris_template_router)
app.include_router(weather_router)
app.include_router(wind_park_router)
