from pathlib import Path
from typing import Annotated

from fastapi import APIRouter, Request, Form, Depends
from fastapi.responses import HTMLResponse
from fastapi.templating import Jinja2Templates

from data.repository import WeatherRepository
from data.schemas import SFlorisInputParams

from routers.floris_router import get_windmill_data

templates = Jinja2Templates(directory=Path("../templates/floris_templates"))

router = APIRouter(
    prefix="",
    tags=["floris_template"],
    include_in_schema=False,
)


@router.get("/", response_class=HTMLResponse)
async def get_main(request: Request, context: dict | None = None):
    if context is None:
        context = {}

    params = {"request": request, "weather": WeatherRepository.get_all()}

    if context is not None:
        params.update(context)

    return templates.TemplateResponse("main.html", params)


def transform_windmill_data(
    options: Annotated[str, Form()],
    x: Annotated[str, Form()],
    y: Annotated[str, Form()]
) -> SFlorisInputParams | None:

    if not all([options, x, y]):
        return None

    return SFlorisInputParams(
        weather_id=int(options),
        layout_x=list(map(float, x.split())),
        layout_y=list(map(float, y.split())),
    )


@router.post("/", response_class=HTMLResponse)
async def post_main(
        request: Request,
        windmill_params: Annotated[SFlorisInputParams | None, Depends(transform_windmill_data)] = None,
):
    if windmill_params is None:
        return await get_main(request)

    data = await get_windmill_data(windmill_params)
    context = {
        'data': data.data,
        'file_name': data.file_name,
    }

    return await get_main(request, context)
